@@ -248,6 +248,9 @@ static int load_setup (struct starter_config *cfg
 	    case kt_idtype:
 		err++;
 		break;
+
+	    case kt_comment:
+		break;
 	    }
 	}
 		
@@ -364,8 +367,11 @@ static int validate_end(struct starter_conn *conn_st
     {
 	char *value = end->strings[KSCF_NEXTHOP];
 	
+	end->nexttype = KH_IPADDR;
+
 	er = ttoaddr(value, 0, AF_INET, &(end->nexthop));
 	if (er) ERR_FOUND("bad addr %snexthop=%s [%s]", leftright, value, er);
+
     } else {
 	if(conn_st->policy & POLICY_OPPO) {
 	    end->nexttype = KH_DEFAULTROUTE;
@@ -682,6 +688,9 @@ bool translate_conn (struct starter_conn *conn
 	    (*the_options)[field] = kw->number;
 	    (*set_options)[field] = TRUE;
 	    break;
+	    
+	case kt_comment:
+	    break;
 	}
     }
     return err;
